aboutsummaryrefslogtreecommitdiffstats
path: root/src/vpp-api/vom/route_domain_cmds.cpp
diff options
context:
space:
mode:
authorNeale Ranns <neale.ranns@cisco.com>2017-11-03 04:39:05 -0700
committerNeale Ranns <nranns@cisco.com>2017-11-06 17:44:21 +0000
commit9ef1c0adbf9399c55deeede3cf629dd4e8c20304 (patch)
tree0eeed8f869eee35a48797b6b837c16222a627e46 /src/vpp-api/vom/route_domain_cmds.cpp
parentaddb55b9e0533c5f720b1cc1bdeeb4bbd0e6bf2a (diff)
VOM reshuffle
split the VOM into two halves; a top/front-end and a bottom/backend. Only the backend includes the auto-generated VAPI. This serves two purposes: 1 - improves ompile times for VOM, since the VAPI is included only in the backend. 2 - does not expose VAPI to users of VOM Change-Id: I17b93aeaef10c0eba8612016d9034aca5628d9f7 Signed-off-by: Neale Ranns <neale.ranns@cisco.com> Signed-off-by: Mohsin Kazmi <sykazmi@cisco.com>
Diffstat (limited to 'src/vpp-api/vom/route_domain_cmds.cpp')
-rw-r--r--src/vpp-api/vom/route_domain_cmds.cpp44
1 files changed, 23 insertions, 21 deletions
diff --git a/src/vpp-api/vom/route_domain_cmds.cpp b/src/vpp-api/vom/route_domain_cmds.cpp
index c3f817f79f1..845497f5989 100644
--- a/src/vpp-api/vom/route_domain_cmds.cpp
+++ b/src/vpp-api/vom/route_domain_cmds.cpp
@@ -13,13 +13,14 @@
* limitations under the License.
*/
-#include "vom/route_domain.hpp"
+#include "vom/route_domain_cmds.hpp"
namespace VOM {
+namespace route_domain_cmds {
-route_domain::create_cmd::create_cmd(HW::item<bool>& item,
- l3_proto_t proto,
- route::table_id_t id)
+create_cmd::create_cmd(HW::item<bool>& item,
+ l3_proto_t proto,
+ route::table_id_t id)
: rpc_cmd(item)
, m_id(id)
, m_proto(proto)
@@ -27,13 +28,13 @@ route_domain::create_cmd::create_cmd(HW::item<bool>& item,
}
bool
-route_domain::create_cmd::operator==(const create_cmd& other) const
+create_cmd::operator==(const create_cmd& other) const
{
return (m_id == other.m_id);
}
rc_t
-route_domain::create_cmd::issue(connection& con)
+create_cmd::issue(connection& con)
{
msg_t req(con.ctx(), std::ref(*this));
@@ -50,7 +51,7 @@ route_domain::create_cmd::issue(connection& con)
}
std::string
-route_domain::create_cmd::to_string() const
+create_cmd::to_string() const
{
std::ostringstream s;
s << "ip-table-create: " << m_hw_item.to_string() << " id:" << m_id
@@ -59,9 +60,9 @@ route_domain::create_cmd::to_string() const
return (s.str());
}
-route_domain::delete_cmd::delete_cmd(HW::item<bool>& item,
- l3_proto_t proto,
- route::table_id_t id)
+delete_cmd::delete_cmd(HW::item<bool>& item,
+ l3_proto_t proto,
+ route::table_id_t id)
: rpc_cmd(item)
, m_id(id)
, m_proto(proto)
@@ -69,13 +70,13 @@ route_domain::delete_cmd::delete_cmd(HW::item<bool>& item,
}
bool
-route_domain::delete_cmd::operator==(const delete_cmd& other) const
+delete_cmd::operator==(const delete_cmd& other) const
{
return (m_id == other.m_id);
}
rc_t
-route_domain::delete_cmd::issue(connection& con)
+delete_cmd::issue(connection& con)
{
msg_t req(con.ctx(), std::ref(*this));
@@ -93,7 +94,7 @@ route_domain::delete_cmd::issue(connection& con)
}
std::string
-route_domain::delete_cmd::to_string() const
+delete_cmd::to_string() const
{
std::ostringstream s;
s << "ip-table-delete: " << m_hw_item.to_string() << " id:" << m_id
@@ -101,11 +102,12 @@ route_domain::delete_cmd::to_string() const
return (s.str());
}
-}
-/*
- * fd.io coding-style-patch-verification: ON
- *
- * Local Variables:
- * eval: (c-set-style "mozilla")
- * End:
- */
+} // namespace route_domain_cmds
+} // namespace VOM
+ /*
+ * fd.io coding-style-patch-verification: ON
+ *
+ * Local Variables:
+ * eval: (c-set-style "mozilla")
+ * End:
+ */